@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11336 2019-01-15 06:39:03Z Lavender $
+# $Id: views.py 11339 2019-01-15 14:56:17Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-01-15 15:39:03 +0900 (週二, 15 一月 2019) $
-# $Revision: 11336 $ 
+# $Date: 2019-01-15 23:56:17 +0900 (週二, 15 一月 2019) $
+# $Revision: 11339 $ 
 
 import json
 import logging
@@ -213,6 +213,43 @@ from des.models import DynamicEmailConfiguration
 from django.contrib.sites.models import Site
 from oscar.apps.order.processing import EventHandler
 
+def sendOrderEmail(order, subjectTemp, htmlTemp, txtTemp):
+    try:
+        temp = get_template(subjectTemp)
+        ctx = Context({
+            "order": order,
+            "site": Site.objects.get(id=settings.SITE_ID)
+        })
+        subject = temp.render(ctx)
+        
+        temp = get_template(htmlTemp)
+        htmlContent = temp.render(ctx)
+                    
+        temp = get_template(txtTemp)
+        txtContent = temp.render(ctx)
+        
+        if order.user:
+            email = order.user.email
+        else:
+            email = order.guest_email
+                            
+        success = send_mail(
+            subject,
+            txtContent,
+            DynamicEmailConfiguration.objects.get().from_email,
+            [email,],
+            html_message=htmlContent,
+            fail_silently=False,
+        )
+                            
+        if success:
+            logger.info("Send order email success: %s" % email)
+        else:
+            logger.error("Send order email fail: %s" % email)
+    except Exception as e:
+        logger.error("Error Send order email: %s" % e)
+    
+
 def handle_order_status_change(self, order, new_status, note_msg=None):
     """
     Handle a requested order status change
@@ -223,43 +260,26 @@ def handle_order_status_change(self, order, new_status, note_msg=None):
     """
     order.set_status(new_status)
 
-    hasSettings = hasattr(settings, 'OSCAR_ORDER_SEND_EMAIL_STATUS')
-    if hasSettings and new_status == settings.OSCAR_ORDER_SEND_EMAIL_STATUS:
-        try:
-            temp = get_template(
-                'shop/customer/emails/BeingProcessedSubject.txt')
-            ctx = Context({
-                "order": order,
-                "site": Site.objects.get(id=settings.SITE_ID)
-            })
-            subject = temp.render(ctx)
-            
-            temp = get_template('shop/customer/emails/BeingProcessedBody.html')
-            htmlContent = temp.render(ctx)
-                        
-            temp = get_template('shop/customer/emails/BeingProcessedBody.txt')
-            txtContent = temp.render(ctx)
-            
-            if order.user:
-                email = order.user.email
-            else:
-                email = order.guest_email
-                                
-            success = send_mail(
-                subject,
-                txtContent,
-                DynamicEmailConfiguration.objects.get().from_email,
-                [email,],
-                html_message=htmlContent,
-                fail_silently=False,
-            )
-                                
-            if success:
-                logger.info("Send order email success: %s" % email)
-            else:
-                logger.error("Send order email fail: %s" % email)
-        except Exception as e:
-            logger.error("Error Send order email: %s" % e)
+    hasSettings = hasattr(settings, 'OSCAR_PROCESSING_SEND_EMAIL_STATUS')
+    
+    if (hasSettings and 
+        new_status == settings.OSCAR_PROCESSING_SEND_EMAIL_STATUS):
+        sendOrderEmail(
+            order, 
+            'shop/customer/emails/BeingProcessedSubject.txt', 
+            'shop/customer/emails/BeingProcessedBody.html', 
+            'shop/customer/emails/BeingProcessedBody.txt'
+        )
+    hasSettings = hasattr(settings, 'OSCAR_ARRIVE_SEND_EMAIL_STATUS')
+    
+    if hasSettings and new_status == settings.OSCAR_ARRIVE_SEND_EMAIL_STATUS:
+        sendOrderEmail(
+            order, 
+            'shop/customer/emails/ArriveSubject.txt', 
+            'shop/customer/emails/ArriveBody.html', 
+            'shop/customer/emails/ArriveBody.txt'
+        )
+        
     
     if note_msg:
         self.create_note(order, note_msg)
@@ -983,8 +1003,10 @@ class ECPayServerReplyView(generic.View):
 
                 order = Order.objects.get(basket=self.basketId)
 
-                if self.rtnCode in ['2030', '3024', '2063', '3018']:
+                if self.rtnCode in ['2030', '3024',]:
                     order.status = settings.OSCAR_ORDER_PROCESSING_STATUS
+                elif self.rtnCode in ['2063', '3018', '2073',]:
+                    order.status = settings.OSCAR_ORDER_ARRIVE_STATUS
                 elif self.rtnCode in ['2067', '3022']:
                     order.status = settings.OSCAR_ORDER_COMPLETE_STATUS
                 elif self.rtnCode in ['2074', '3020']:
@@ -992,6 +1014,28 @@ class ECPayServerReplyView(generic.View):
                 else:
                     return HttpResponse("|ErrorMessage")
                 order.save()
+                
+                hasSettings = hasattr(
+                    settings, 'OSCAR_PROCESSING_SEND_EMAIL_STATUS')
+                if (hasSettings and 
+                    order.status == \
+                        settings.OSCAR_PROCESSING_SEND_EMAIL_STATUS):
+                    sendOrderEmail(
+                        order, 
+                        'shop/customer/emails/BeingProcessedSubject.txt', 
+                        'shop/customer/emails/BeingProcessedBody.html', 
+                        'shop/customer/emails/BeingProcessedBody.txt'
+                    )
+                hasSettings = hasattr(
+                    settings, 'OSCAR_ARRIVE_SEND_EMAIL_STATUS')
+                if (hasSettings and 
+                    order.status == settings.OSCAR_ARRIVE_SEND_EMAIL_STATUS):
+                    sendOrderEmail(
+                        order, 
+                        'shop/customer/emails/ArriveSubject.txt', 
+                        'shop/customer/emails/ArriveBody.html', 
+                        'shop/customer/emails/ArriveBody.txt'
+                    )
 
                 logisticTrade = ECPayLogisticTrade.objects.filter(
                     tradeNo=self.tradeNo).order_by('-id').first()
