@@ -28,9 +28,10 @@ except NameError:
     FileNotFoundError = IOError
 
 class GosTest(unittest.TestCase):
-    TEST_FOLDER = "GosTest"
+    TEST_FOLDER = 'CI/Tests/Iuno.cloud.storage'
+    TEST_FOLDER_ID = '1kSTFKkrQAfNuZjQgN6jBHBIZzhHYtr7w'
     RESULT_FILE_DICT = {
-        'id': '1upj4wrXwcjfztMr4ZXFQsMBBe7ThssHS',
+        'id': '1ellDpAhS3XqWPav6wD0xunOpaWpxrrt3',
         'name': 'plane.jpg'
     }
 
@@ -61,7 +62,7 @@ class GosTest(unittest.TestCase):
                           lambda: os.getFile("20MB", type=BY_SIZE))
 
     def testGetFiles(self):
-        folderId = "1JTx-WWHwY5K2pPZoZpzoIheNtet7W4V-"  # 我的雲端硬碟/GosTest
+        folderId = self.TEST_FOLDER_ID
         result = os.getFiles(folderId)
 
         self.assertEqual(len(result), 1)
@@ -123,7 +124,7 @@ class GosTest(unittest.TestCase):
                 "%Y:%m:%d %H:%M:%S"
             ),
             os.path.getctime(
-                'GosTest/plane.jpg',
+                os.path.join(self.TEST_FOLDER, 'plane.jpg'),
                 property='imageMediaMetadata',
                 subProperty="time",
                 timeFormat="%Y:%m:%d %H:%M:%S"
@@ -132,8 +133,8 @@ class GosTest(unittest.TestCase):
 
         # creation time
         self.assertEqual(
-            parser.parse("2018-11-08T19:51:15.126Z"),
-            os.path.getctime('GosTest/plane.jpg',)
+            parser.parse("2018-12-07T06:38:00.233Z"),
+            os.path.getctime(os.path.join(self.TEST_FOLDER, 'plane.jpg'))
         )
 
 
